@@ -21,25 +21,29 @@
 """Context management."""
 
 
-import sys
-import os
-import glob
-import traceback
-import operator
-import random
 import gettext
-_ = lambda m: gettext.dgettext(message=m, domain='otopi')
+import glob
+import operator
+import os
+import random
+import sys
+import traceback
 
 
+from . import base
+from . import command
+from . import common
 from . import config
 from . import constants
-from . import base
-from . import util
-from . import plugin
 from . import dialog
-from . import services
 from . import packager
-from . import command
+from . import plugin
+from . import services
+from . import util
+
+
+def _(m):
+    return gettext.dgettext(message=m, domain='otopi')
 
 
 @util.export
@@ -208,6 +212,12 @@ class Context(base.Base):
             constants.BaseEnv.ERROR: False,
             constants.BaseEnv.ABORTED: False,
             constants.BaseEnv.EXCEPTION_INFO: [],
+            constants.BaseEnv.EXIT_CODE: [
+                {
+                    'priority': plugin.Stages.PRIORITY_LAST + 1,
+                    'code': constants.Const.EXIT_CODE_SUCCESS,
+                },
+            ],
             constants.BaseEnv.EXECUTION_DIRECTORY: '.',
             constants.BaseEnv.SUPPRESS_ENVIRONMENT_KEYS: [],
             constants.BaseEnv.LOG: False,
@@ -426,7 +436,7 @@ class Context(base.Base):
                         not self.environment[constants.BaseEnv.ERROR]
                     ):
                         oldEnvironment = dict(
-                            (k, str(v))
+                            (k, common.toStr(v))
                             for k, v in self.environment.items()
                         )
                         self._executeMethod(self._currentStage, methodinfo)
@@ -479,11 +489,11 @@ class Context(base.Base):
         """Dump environment."""
         diff = False
         for key in sorted(self.environment.keys()):
-            value = str(self.environment[key])
+            value = common.toStr(self.environment[key])
 
             if (
                 old is None or
-                value != str(old.get(key))
+                value != common.toStr(old.get(key))
             ):
                 if not diff:
                     diff = True
